<?php

namespace Drupal\cforge_address;

use Drupal\mcapi\Entity\Storage\WalletStorage;
use Drupal\migrate\MigrateSkipRowException;
use Drupal\migrate\Event\MigratePreRowSaveEvent;
use Drupal\migrate\Event\MigratePostRowSaveEvent;
use Drupal\migrate\Event\MigrateImportEvent;
use Drupal\migrate\Row;
use Drupal\user\Entity\User;
use Drupal\user\Entity\Role;
use Drupal\field\Entity\FieldConfig;
use Drupal\Core\Entity\Entity\EntityFormDisplay;
use Drupal\Core\Entity\Entity\EntityViewDisplay;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\Core\Menu\MenuTreeParameters;


/**
 * Migration modifications
 *
 * Note the order of events in MigrateExecutable::import
 * Dispatch PRE_IMPORT
 *  $source->next
 *  $source->prepareRow
 *    hook_migrate_prepare_row
 *    hook_migrate_NAME_prepare_row
 *  while
 *    processRow
 *    Dispatch PRE_ROW_SAVE
 *    Dispatch POST_ROW_SAVE
 *  Dispatch POST_IMPORT
 *
 */
class MigrationSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() : array {
    return [
      'migrate.pre_row_save' => [['migratePreRowSave']],
    ];
  }


  /**
   * @param Drupal\migrate\Event\MigratePreRowSaveEvent $event
   */
  public function migratePreRowSave(MigratePreRowSaveEvent $event) {
    $row = $event->getRow();
    $migration = $event->getMigration();
    if ($migration->id() == 'd7_field' or $migration->id() == 'd7_field_instance') {
      if ($row->getSourceProperty('field_name') == 'profile_address') {
        throw new MigrateSkipRowException('Not migrating user address field');
      }
    }
    if ($migration->id() == 'd7_user') {
      $address = $row->getSourceProperty('profile_address');
      $dest_address = $this->transformAddress($address[0]);
      $row->setDestinationProperty('address', [$dest_address]);
      $row->removeDestinationProperty('profile_address');
    }
  }

  // All this is necessary because the address/src/Plugin/migrate/process/AddressField.php isn't running
  private function transformAddress($value) {
    $parsed = [
      'country_code' => $value['country'],
      'administrative_area' => $value['administrative_area'],
      'locality' => $value['locality'],
      'dependent_locality' => $value['dependent_locality'],
      'postal_code' => $value['postal_code'],
      'sorting_code' => '',
      'address_line1' => $value['thoroughfare'],
      'address_line2' => $value['premise'],
      'organization' => $value['organisation_name'],
    ];
    if (!empty($value['first_name']) || !empty($value['last_name'])) {
      $parsed['given_name'] = $value['first_name'];
      $parsed['family_name'] = $value['last_name'];
    }
    elseif (!empty($value['name_line'])) {
      $split = explode(" ", $value['name_line']);
      $parsed['given_name'] = array_shift($split);
      $parsed['family_name'] = implode(' ', $split);
    }
    return $parsed;
  }


}
